<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       http://example.com
 * @since      1.0.0
 *
 * @package    Plugin_Name
 * @subpackage Plugin_Name/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Plugin_Name
 * @subpackage Plugin_Name/admin
 * @author     Your Name <email@example.com>
 */
class Pod_Plugin_Admin
{

    /**
     * The ID of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string $plugin_name The ID of this plugin.
     */
    private $plugin_name;

    /**
     * The version of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string $version The current version of this plugin.
     */
    private $version;

    /**
     * Initialize the class and set its properties.
     *
     * @param string $plugin_name The name of this plugin.
     * @param string $version The version of this plugin.
     * @since    1.0.0
     */
    public function __construct($plugin_name, $version)
    {

        $this->plugin_name = $plugin_name;
        $this->version = $version;

    }

    /**
     * Register the stylesheets for the admin area.
     *
     * @since    1.0.0
     */
    public function enqueue_styles()
    {

        /**
         * This function is provided for demonstration purposes only.
         *
         * An instance of this class should be passed to the run() function
         * defined in Plugin_Name_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The Plugin_Name_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
         */

        //wp_enqueue_style($this->plugin_name, plugin_dir_url(__FILE__) . 'css/plugin-name-admin.css', array(), $this->version, 'all');

    }

    /**
     * Register the JavaScript for the admin area.
     *
     * @since    1.0.0
     */
    public function enqueue_scripts()
    {

        /**
         * This function is provided for demonstration purposes only.
         *
         * An instance of this class should be passed to the run() function
         * defined in Plugin_Name_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The Plugin_Name_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
         */

        // wp_enqueue_script($this->plugin_name, plugin_dir_url(__FILE__) . 'js/plugin-name-admin.js', array('jquery'), $this->version, false);

    }

    public function addPodServices()
    {
        register_rest_route('pod-plugin', 'product-hooks', [
            'methods' => 'POST',
            'callback' => 'ServiceHandleProductHooks'
        ]);

        register_rest_route('pod-plugin', 'order-hooks', [
            'methods' => 'POST',
            'callback' => 'ServiceHandleOrderHooks'
        ]);

    }

    public function AddAdminConfigMenu()
    {
        add_options_page('PODPLUGIN', 'پادچاپ', 'manage_options', 'pod-plugin', 'handelPodConfigPage');
    }


    public function AddPodOrderColumn($columns)
    {
        $columns['pod-order'] = __('عملیات پاد', 'woocommerce');
        return $columns;
    }

//    public function isPodOrder($wp_order)
//    {
//
//        $order_items = $wp_order->get_items();
//        foreach ($order_items as $items_key => $items_value) {
//            $prSku=$items_value->get_product()->get_sku();
//            //is_pod_product
//            if (substr($prSku, 0, 3) == 'pod') {
//                return true;
//
//            }
//        }
//
//        return false;
//    }

    public function AddPodOrderColumnContent($column)
    {
        if ('pod-order' === $column) {
            global $the_order;
            $podOrderSendMessage = $the_order->get_meta('pod_order_send_request_message');//_wapp_sent
            $OrderStatusToSendPod = get_option('pod-plugin-options')['order_status'];

            $wp_order_id = $the_order->get_id();
            $wp_order = new WC_Order($wp_order_id);

            $pod_order_id = $wp_order->get_meta('pod_order_id');
            $pod_order_send_request_success = $wp_order->get_meta('pod_order_send_request_success');
            $pod_order_status = $wp_order->get_meta('pod_order_status');


            if ($pod_order_id) {
                $pod_order_id_status = ' شناسه سفارش در سامانه پاد: ' . '#' . $the_order->get_meta('pod_order_id') . "<br/>" . "  وضعیت  سفارش در سامانه پاد:" . $pod_order_status . "<br/>";
                $phone_wp_dashicon = '<span class="dashicons dashicons-warning"></span> ';
                echo '<br><a href="status: ' . $podOrderSendMessage . '">' . $pod_order_id_status . ' ' . $phone_wp_dashicon . 'پیام ارسال سفارش به پاد: ' . $podOrderSendMessage . '</a></strong>';

            }
            if ($wp_order->get_meta('is_pod') == 'true' && $podOrderSendMessage !== 'success send pod ') {
//                if (strtolower($the_order->status) == strtolower($OrderStatusToSendPod)) {
                echo '<a href="?post_type=shop_order&pod_action=createPodOrder&order_id=' . $the_order->get_id() . '"  target="blank" class="dvs-whatsapp button">' . __("ارسال سفارش به پاد") . '</a>';
//                }
            }
        }
    }

    public function on_wp_order_status_changed($order_id)
    {
        $the_order = wc_get_order($order_id);
        $OrderStatusToSendPod = get_option('pod-plugin-options')['order_status'];
        $pod_order_send_request_success = $the_order->get_meta('pod_order_send_request_success');

        if (strtolower($the_order->status) == strtolower($OrderStatusToSendPod) && !$pod_order_send_request_success) {
            send_CreatePodOrderRequest($the_order->get_id());
        }
    }


    function sendWpOrderToPortal()
    {
        global $pagenow;
        if ($pagenow == 'edit.php' && isset($_GET['post_type']) && $_GET['post_type'] == 'shop_order' && isset($_GET['order_id']) && $_GET['order_id'] > 0) {
            if (isset($_GET['pod_action']) && $_GET['pod_action'] == 'createPodOrder') {
                $order_id = $_GET['order_id'];
                send_CreatePodOrderRequest($order_id);
            }
//            elseif (isset($_GET['pod_action']) && $_GET['pod_action'] == 'updatePodOrder') {
//                $order_id = $_GET['order_id'];
//                send_updateOrderFormPodOrder($order_id);
//            }
        }

    }

    public function add_cors_headers()
    {
//        header("Access-Control-Allow-Origin: *");
//        header("Access-Control-Allow-Methods: GET, POST, OPTIONS");
//        header("Access-Control-Allow-Headers: Origin, X-Requested-With, Content-Type, Accept");

        $origin = get_http_origin();
        if ($origin === POD_BASE_URL) {
            header("Access-Control-Allow-Origin: *");
            header("Access-Control-Allow-Methods: POST, GET, OPTIONS, PUT, DELETE");
            header("Access-Control-Allow-Credentials: true");
            header('Access-Control-Allow-Headers: Origin, X-Requested-With, X-WP-Nonce, Content-Type, Accept, Authorization, X-Auth-Token, X-Api-Date-Time, X-Api-Key');
            if ('OPTIONS' == $_SERVER['REQUEST_METHOD']) {
                status_header(200);
                exit();
            }
        }
    }

    public function set_is_pod_meta_for_new_order($order_id)
    {

        $order = wc_get_order($order_id);

        $contains_pod_sku = false;
        foreach ($order->get_items() as $item_id => $item) {
            $product = $item->get_product();
            $sku = $product->get_sku();
            if (substr($sku, 0, 3) === 'pod') {
                $contains_pod_sku = true;
                break;
            }
        }
        if ($contains_pod_sku) {
            update_post_meta($order_id, 'is_pod', 'true');
        }
    }

    public function check_and_remove_is_pod_meta( $item_id ) {
        global $wpdb;

        $order_id = $wpdb->get_var( $wpdb->prepare( "
        SELECT order_id 
        FROM {$wpdb->prefix}woocommerce_order_items 
        WHERE order_item_id = %d
    ", $item_id ) );

        $order = wc_get_order( $order_id );

        $contains_pod_sku = false;

        foreach( $order->get_items() as $remaining_item_id => $remaining_item ) {
            if ( $remaining_item_id == $item_id ) {
                continue;
            }

            $product = $remaining_item->get_product();
            $sku = $product->get_sku();
            if ( substr( $sku, 0, 3 ) === 'pod' ) {
                $contains_pod_sku = true;
                break;
            }
        }

        if ( ! $contains_pod_sku ) {
            delete_post_meta( $order_id, 'is_pod' );
        }
    }

}