<?php
function send_CreatePodOrderRequest($wp_order_id)
{
    try {
        $api_date_time = time();
        $pod_plugin_options = get_option('pod-plugin-options');
        $api_key = $pod_plugin_options['pod_api_key'];
        $secret_key = $pod_plugin_options['pod_api_secret_key'];
        $t = ($api_key . ':' . base64_encode(hash_hmac(POD_AUTH_HASH, $api_date_time, $secret_key, true)));

        $sendWpOrderAsPodOrderUrl = POD_BASE_URL . POD_ORDERS_SERVICE_CREATE_URL;
        $bodyRequest = [
            "headers" => [
                'X-API-KEY' => $t,
                'X-API-DATE-TIME' => $api_date_time,
            ],
            'body' => createPodOrderRequest($wp_order_id),
            'timeout' => 30,
            'connect_timeout' => 10,
            'sslverify' => false // Consider making this configurable
        ];

        PodPluginLogMessage($bodyRequest['body']);

        $api_response = wp_remote_post($sendWpOrderAsPodOrderUrl, $bodyRequest);
        $json = wp_remote_retrieve_body($api_response);
        LogPodApiCall(POD_ORDERS_SERVICE_CREATE_URL, 'request-response', [
            'request' => $bodyRequest,
            'response' => $api_response
        ]);

        $status_code = wp_remote_retrieve_response_code($api_response);

        $wp_order = new WC_Order($wp_order_id);
        $json_array = json_decode($json, true);

        if ($status_code != 200) {
            $wp_order->update_meta_data('pod_order_send_request_message', 'send order response is' . $status_code);
            $wp_order->update_meta_data('pod_order_send_request_success', false);
            $wp_order->save();
            return;
        }


        if (!$json_array['success']) {
            $wp_order->update_meta_data('pod_order_send_request_message', $json_array['message']);
            $wp_order->update_meta_data('pod_order_send_request_success', false);
            $wp_order->save();
            return;
        }

//    LogPodApiCall('/orders/meta', 'set sku for product ' . $wp_product_id . ' and sku:' . $pod_product_item_sku, []);


        $pod_order_id = $json_array['data']['order']['id'];
        $pod_order_status = $json_array['data']['order']['status'];
        $pod_order_reference = $json_array['data']['order']['reference'];
        //todo add error
        //PodPluginLog($pod_order_id,$pod_order_status);
        //PodPluginLog($order->get_id());toDo

        $wp_order->update_meta_data('pod_order_send_request_message', 'success send pod ');
        $wp_order->update_meta_data('pod_order_send_request_success', true);
        $wp_order->update_meta_data('pod_order_id', $pod_order_id);
        $wp_order->update_meta_data('pod_order_status', $pod_order_status);
        $wp_order->update_meta_data('pod_order_reference', $pod_order_reference);
        $wp_order->save();

        return;

    } catch (\Exception|Throwable $e) {
        LogPodApiCall(POD_ORDERS_SERVICE_CREATE_URL, 'an error: ' . $e->getMessage(), [
            'wp_order_id' => $wp_order_id
        ]);
        return;
    }

}


