<?php
function slugify2($string)
{
    $separator = '-';
    $_transliteration = ["/ö|œ/" => "e",
        "/ü/" => "e",
        "/Ä/" => "e",
        "/Ü/" => "e",
        "/Ö/" => "e",
        "/À|Á|Â|Ã|Å|Ǻ|Ā|Ă|Ą|Ǎ/" => "",
        "/à|á|â|ã|å|ǻ|ā|ă|ą|ǎ|ª/" => "",
        "/Ç|Ć|Ĉ|Ċ|Č/" => "",
        "/ç|ć|ĉ|ċ|č/" => "",
        "/Ð|Ď|Đ/" => "",
        "/ð|ď|đ/" => "",
        "/È|É|Ê|Ë|Ē|Ĕ|Ė|Ę|Ě/" => "",
        "/è|é|ê|ë|ē|ĕ|ė|ę|ě/" => "",
        "/Ĝ|Ğ|Ġ|Ģ/" => "",
        "/ĝ|ğ|ġ|ģ/" => "",
        "/Ĥ|Ħ/" => "",
        "/ĥ|ħ/" => "",
        "/Ì|Í|Î|Ï|Ĩ|Ī| Ĭ|Ǐ|Į|İ/" => "",
        "/ì|í|î|ï|ĩ|ī|ĭ|ǐ|į|ı/" => "",
        "/Ĵ/" => "",
        "/ĵ/" => "",
        "/Ķ/" => "",
        "/ķ/" => "",
        "/Ĺ|Ļ|Ľ|Ŀ|Ł/" => "",
        "/ĺ|ļ|ľ|ŀ|ł/" => "",
        "/Ñ|Ń|Ņ|Ň/" => "",
        "/ñ|ń|ņ|ň|ŉ/" => "",
        "/Ò|Ó|Ô|Õ|Ō|Ŏ|Ǒ|Ő|Ơ|Ø|Ǿ/" => "",
        "/ò|ó|ô|õ|ō|ŏ|ǒ|ő|ơ|ø|ǿ|º/" => "",
        "/Ŕ|Ŗ|Ř/" => "",
        "/ŕ|ŗ|ř/" => "",
        "/Ś|Ŝ|Ş|Ș|Š/" => "",
        "/ś|ŝ|ş|ș|š|ſ/" => "",
        "/Ţ|Ț|Ť|Ŧ/" => "",
        "/ţ|ț|ť|ŧ/" => "",
        "/Ù|Ú|Û|Ũ|Ū|Ŭ|Ů|Ű|Ų|Ư|Ǔ|Ǖ|Ǘ|Ǚ|Ǜ/" => "",
        "/ù|ú|û|ũ|ū|ŭ|ů|ű|ų|ư|ǔ|ǖ|ǘ|ǚ|ǜ/" => "",
        "/Ý|Ÿ|Ŷ/" => "",
        "/ý|ÿ|ŷ/" => "",
        "/Ŵ/" => "",
        "/ŵ/" => "",
        "/Ź|Ż|Ž/" => "",
        "/ź|ż|ž/" => "",
        "/Æ|Ǽ/" => "E",
        "/ß/" => "s",
        "/Ĳ/" => "J",
        "/ĳ/" => "j",
        "/Œ/" => "E",
        "/ƒ/" => ""];
    $quotedReplacement = preg_quote($separator, '/');
    $merge = [
        '/[^\s\p{Zs}\p{Ll}\p{Lm}\p{Lo}\p{Lt}\p{Lu}\p{Nd}]/mu' => ' ',
        '/[\s\p{Zs}]+/mu' => $separator,
        sprintf('/^[%s]+|[%s]+$/', $quotedReplacement, $quotedReplacement) => '',
    ];
    $map = $_transliteration + $merge;
    unset($_transliteration);
    return preg_replace(array_keys($map), array_values($map), $string);
}


function slugify($str)
{
    $divider = '-';
    $text = preg_replace('~-+~', $divider, $str);
    $text = str_replace(' ', $divider, $str);
    return $text;
}

function getProductAttributeSlug($slug, $name, $type = 'select')
{
    global $wpdb;

    $slug = 'att_pod_' . $slug;
    $attribute_id = $wpdb->get_var(
        $wpdb->prepare(
            "
				SELECT attribute_id
				FROM {$wpdb->prefix}woocommerce_attribute_taxonomies
				WHERE attribute_name = %s
			",
            $slug
        )
    );

    $def = array(
        'slug' => $slug,
        'name' => __($name, $name),
        'type' => $type,
        'orderby' => 'menu_order',
        'has_archives' => true,
    );


    if ($attribute_id) {
        $def['id'] = $attribute_id;
        $result = wc_update_attribute($attribute_id, $def);
    } else {
        $result = wc_create_attribute($def);
    }

    return wc_get_attribute($result)->slug;
}

function GetOrCreateCategoryIfNotExist($name)
{

    $slug = slugify($name);
    wp_insert_term($name, 'product_cat', array(
        'description' => $name,
        'parent' => 0,
        'slug' => $slug
    ));
    $cat = get_term_by('slug', $slug, 'product_cat');
    return $cat->term_id;
}

function GetOrCreateTagIfNotExist($name)
{
    global $wpdb;
    $slug = slugify($name);
    wp_insert_term($name, 'product_tag', array(
        'description' => $name,
        'parent' => 0,
        'slug' => $slug
    ));
    $cat = get_term_by('slug', $slug, 'product_tag');
    return $cat->term_id;
}


function createPodMetaForWpProduct($wp_product_id, $pod_product_item_sku)
{
    update_post_meta($wp_product_id, 'is_pod_product', true);
    update_post_meta($wp_product_id, 'pod_product_sku', $pod_product_item_sku);
    update_post_meta($wp_product_id, 'pod_product_id', true);
    wp_update_post(array('ID' => $wp_product_id));
}

function updateWpProduct($wp_product_id, PodProductItem $pod_product_item_object)
{
    $pod_main_delivery_time=$pod_product_item_object->getDelivryTimePod();

    $wp_product = wc_get_product($wp_product_id);

    if( $wp_product->is_type( 'simple' ) ) {
    $wp_product->set_name($pod_product_item_object->getTitle());
   // $attribute->set_description(str_replace("DAY",$pod_main_delivery_time +POD_ADDITIONAL_TIME_DELIVERY, POD_TEXT_DELIVERY));
    $wp_product->set_status('publish');
    $wp_product->set_catalog_visibility('visible');
    $wp_product->set_short_description($pod_product_item_object->getSummeryAsAttrubte());
    $original_price_pod = $pod_product_item_object->getPodOriginalPrice();
    $wp_product->set_price($original_price_pod);
    $wp_product->set_regular_price($original_price_pod);
    $wp_product->set_sold_individually(false);
    $stock_status = $pod_product_item_object->getSalable();
    $wp_product->set_stock_status($stock_status);
    $wp_product->set_sold_individually(false);
    //$product->set_category_ids( array( 1 ) );
    $wp_product->save();}
    elseif ($wp_product->is_type( 'variable' )){
        setWpProductAttributeVariable($wp_product, $pod_product_item_object);
    }


    $cat_id = GetOrCreateCategoryIfNotExist($pod_product_item_object->getMainCategoryName());
    $wp_product->set_category_ids([$cat_id]);

    $tags_id = [];
    foreach ($pod_product_item_object->getTagName() as $tagName) {
        $tag_id = GetOrCreateTagIfNotExist($tagName);
        if ($tag_id)
            $tags_id[] = $tag_id;
    }
    $wp_product->set_tag_ids($tags_id);

    $wp_product->save();
    return $wp_product_id;
}


function CreateWpProduct(PodProductItem $pod_product_item_object)
{
    $pod_plugin_options = get_option('pod-plugin-options');
    $product_type_YPod_NStore = $pod_plugin_options['select_product1'];
    $product_type_NPod_YStore = $pod_plugin_options['select_product2'];


    if ($product_type_YPod_NStore == 'variant_1') {
        $ref_id=   product_type_YPod_NStore_Variable($pod_product_item_object);
       // var_dump($ref_id);
    } elseif ($product_type_YPod_NStore == 'simple_1') {
        $ref_id=  product_type_YPod_NStore_Simple($pod_product_item_object);
    }

    if ($product_type_NPod_YStore == 'variant_2') {

       // var_dump(!is_null($pod_product_item_object->store->reference_id));

        if (!is_null($pod_product_item_object->store->reference_id)) {



            $ref_id = $pod_product_item_object->store->reference_id;
            $sku = getSkubyPostId($ref_id);


            if (str_starts_with($sku, 'pod-book')) {
                updateWpProduct($ref_id, $pod_product_item_object);
            } else {
                $product = wc_get_product($ref_id);

;

                if( $product->is_type( 'simple' ) ) {

                    wp_remove_object_terms($ref_id, 'simple', 'product_type');
                    wp_set_object_terms($ref_id, 'variable', 'product_type', true);

                    $product->set_sku($pod_product_item_object->get_sku());
                    attribute_type_YPod_NStore_Simple($product, $pod_product_item_object);
                }else{
                    $product->set_sku($pod_product_item_object->get_sku());
                    attribute_type_YPod_NStore_Simple($product, $pod_product_item_object);
                }
            }
        }



        $tags_id = [];
        foreach ($pod_product_item_object->getTagName() as $tagName) {
            $tag_id = GetOrCreateTagIfNotExist($tagName);
            if ($tag_id)
                $tags_id[] = $tag_id;
        }
        $product->set_tag_ids($tags_id );
        // wp_set_post_terms($wp_product_id, $tags_id, 'product', true);
        $product->save();

        //check toDo



    }
    elseif ($product_type_NPod_YStore == 'simple_2') {$ref_id= product_type_YPod_NStore_Simple($pod_product_item_object); print_r('dsfsd');}

    //var_dump($ref_id);
    return $ref_id;
}

function AddOrUpdateWpProductBaseOnPopProductItem($pod_product_item)
{
    global $wpdb;

    try {
        $pod_product_item = new PodProductItem($pod_product_item);

        $pod_product_item_sku = $pod_product_item->gerPodSKU();
        $pod_sent_wp_product_reference_id = $pod_product_item->getStoreReferenceId();


        $sql = "SELECT post_id FROM  {$wpdb->prefix}postmeta  WHERE meta_key='pod_product_sku' AND meta_value ='" . $pod_product_item_sku . "'";
        $wp_product_id_for_pod_product = $wpdb->get_var($sql);


        if (is_null($wp_product_id_for_pod_product)) {

            if ($pod_sent_wp_product_reference_id) {
                $wp_product_id = updateWpProduct($pod_sent_wp_product_reference_id, $pod_product_item);
            } else {
                $wp_product_id = CreateWpProduct($pod_product_item);

            }
            createPodMetaForWpProduct($wp_product_id, $pod_product_item_sku);

        } else {

            $wp_product_id = updateWpProduct($wp_product_id_for_pod_product, $pod_product_item);
        }

        return $wp_product_id;

    } catch
    (Exception $ex) {
        logAPiCallError('/api/v1/store/products', 'add product failed' . $ex->getMessage(), []);
    }

    return 1;

}


function getSkubyPostId($post_id = false)
{
    global $wpdb;
    $sku = $wpdb->get_var(
        $wpdb->prepare("SELECT post_id FROM $wpdb->postmeta WHERE post_id=$post_id AND meta_value='%s' LIMIT 1",
            $post_id)
    );

    if ($sku)
        return $sku;

    return null;
}


?>