<?php

/**
 * The file that defines the core plugin class
 *
 * A class definition that includes attributes and functions used across both the
 * public-facing side of the site and the admin area.
 *
 * @link       http://example.com
 * @since      1.0.0
 *
 * @package    Plugin_Name
 * @subpackage Plugin_Name/includes
 */

/**
 * The core plugin class.
 *
 * This is used to define internationalization, admin-specific hooks, and
 * public-facing site hooks.
 *
 * Also maintains the unique identifier of this plugin as well as the current
 * version of the plugin.
 *
 * @since      1.0.0
 * @package    Plugin_Name
 * @subpackage Plugin_Name/includes
 * @author     Your Name <email@example.com>
 */
class PodPlugin
{

    /**
     * The loader that's responsible for maintaining and registering all hooks that power
     * the plugin.
     *
     * @since    1.0.0
     * @access   protected
     * @var      Pod_Plugin_Loader $loader Maintains and registers all hooks for the plugin.
     */
    protected $loader;

    /**
     * The unique identifier of this plugin.
     *
     * @since    1.0.0
     * @access   protected
     * @var      string $plugin_name The string used to uniquely identify this plugin.
     */
    protected $plugin_name;

    /**
     * The current version of the plugin.
     *
     * @since    1.0.0
     * @access   protected
     * @var      string $version The current version of the plugin.
     */
    protected $version;


    private function set_http_timeout() {
        add_filter('http_request_timeout', function($timeout) {
            return 30; // 30 second timeout
        });
    }
    /**
     * Define the core functionality of the plugin.
     *
     * Set the plugin name and the plugin version that can be used throughout the plugin.
     * Load the dependencies, define the locale, and set the hooks for the admin area and
     * the public-facing side of the site.
     *
     * @since    1.0.0
     */
    public function __construct()
    {
        if (defined('PLUGIN_NAME_VERSION')) {
            $this->version = PLUGIN_NAME_VERSION;
        } else {
            $this->version = '1.0.0';
        }
        $this->plugin_name = 'pod-plugin';

        $this->load_dependencies();
        $this->set_locale();
        $this->set_http_timeout();
        $this->define_admin_hooks();
        $this->define_public_hooks();

    }

    /**
     * Load the required dependencies for this plugin.
     *
     * Include the following files that make up the plugin:
     *
     * - Plugin_Name_Loader. Orchestrates the hooks of the plugin.
     * - Plugin_Name_i18n. Defines internationalization functionality.
     * - Plugin_Name_Admin. Defines all hooks for the admin area.
     * - Plugin_Name_Public. Defines all hooks for the public side of the site.
     *
     * Create an instance of the loader which will be used to register the hooks
     * with WordPress.
     *
     * @since    1.0.0
     * @access   private
     */


    private function load_dependencies()
    {

        /**
         * The class responsible for orchestrating the actions and filters of the
         * core plugin.
         */
        require_once plugin_dir_path(dirname(__FILE__)) . 'includes/class-PodPlugin--loader.php';
        require_once plugin_dir_path(dirname(__FILE__)) . 'log/log.php';


        require_once plugin_dir_path(dirname(__FILE__)) . 'admin/functions/podproducts/PodProductItem.php';
        require_once plugin_dir_path(dirname(__FILE__)) . 'admin/functions/podproducts/UpdateProductBaseOnPodHookProductItem.php';

        require_once plugin_dir_path(dirname(__FILE__)) . 'admin/functions/podproducts/productHooksHandler.php';

        require_once plugin_dir_path(dirname(__FILE__)) . 'admin/functions/config/configpage.php';

        require_once plugin_dir_path(dirname(__FILE__)) . 'admin/functions/order/orderHooksHandler.php';
        require_once plugin_dir_path(dirname(__FILE__)) . 'admin/functions/order/sendCreatePodOrderRequest.php';
        require_once plugin_dir_path(dirname(__FILE__)) . 'admin/functions/order/createPodOrderRequest.php';


        /**
         * The class responsible for defining internationalization functionality
         * of the plugin.
         */
        require_once plugin_dir_path(dirname(__FILE__)) . 'includes/class-PodPlugin--i18N.php';

        /**
         * The class responsible for defining all actions that occur in the admin area.
         */
        require_once plugin_dir_path(dirname(__FILE__)) . 'admin/class-PodPlugin--admin.php';

        /**
         * The class responsible for defining all actions that occur in the public-facing
         * side of the site.
         */
        require_once plugin_dir_path(dirname(__FILE__)) . 'public/class-PodPlugin--public.php';

        $this->loader = new Pod_Plugin_Loader();

    }

    /**
     * Define the locale for this plugin for internationalization.
     *
     * Uses the Plugin_Name_i18n class in order to set the domain and to register the hook
     * with WordPress.
     *
     * @since    1.0.0
     * @access   private
     */
    private function set_locale()
    {

        $plugin_i18n = new PodPlugin_i18n();

        $this->loader->add_action('plugins_loaded', $plugin_i18n, 'load_plugin_textdomain');

    }

    /**
     * Register all of the hooks related to the admin area functionality
     * of the plugin.
     *
     * @since    1.0.0
     * @access   private
     */
    private function define_admin_hooks()
    {

        $plugin_admin = new Pod_Plugin_Admin($this->get_plugin_name(), $this->get_version());

        $this->loader->add_action('admin_enqueue_scripts', $plugin_admin, 'enqueue_styles');
        $this->loader->add_action('admin_enqueue_scripts', $plugin_admin, 'enqueue_scripts');

        //to do disable hooks
        //$this->loader->add_action('wp_enqueue_scripts', $plugin_admin, 'api_callings_scripts');

        $this->loader->add_action('rest_api_init', $plugin_admin, 'addPodServices');
        $this->loader->add_action('admin_menu', $plugin_admin, 'AddAdminConfigMenu');
        $this->loader->add_action('init', $plugin_admin, 'add_cors_headers');

        //pod_order columns in orders
//        add_action('init',$plugin_admin->add_cors_headers());
        $this->loader->add_filter('manage_edit-shop_order_columns', $plugin_admin, 'AddPodOrderColumn');
        $this->loader->add_action('manage_shop_order_posts_custom_column', $plugin_admin, 'AddPodOrderColumnContent');

        //send wp order to por portal manually
        $this->loader->add_action('admin_init', $plugin_admin, 'sendWpOrderToPortal');
        $this->loader->add_action('woocommerce_order_status_changed', $plugin_admin, 'on_wp_order_status_changed', 10, 3);

        $this->loader->add_action('woocommerce_new_order', $plugin_admin, 'set_is_pod_meta_for_new_order', 10, 1);

        $this->loader->add_action('woocommerce_before_delete_order_item', $plugin_admin, 'check_and_remove_is_pod_meta', 10, 2);

    }

    /**
     * Register all of the hooks related to the public-facing functionality
     * of the plugin.
     *
     * @since    1.0.0
     * @access   private
     */
    private function define_public_hooks()
    {
        $plugin_public = new PodPlugin_Public($this->get_plugin_name(), $this->get_version());
        $this->loader->add_action('wp_enqueue_scripts', $plugin_public, 'enqueue_styles');
        $this->loader->add_action('wp_enqueue_scripts', $plugin_public, 'enqueue_scripts');
        $this->loader->add_action('pod_order_every_minute', $plugin_public, 'updatePodOrder');
    }

    /**
     * Run the loader to execute all of the hooks with WordPress.
     *
     * @since    1.0.0
     */
    public function run()
    {
        $this->loader->run();
    }

    /**
     * The name of the plugin used to uniquely identify it within the context of
     * WordPress and to define internationalization functionality.
     *
     * @return    string    The name of the plugin.
     * @since     1.0.0
     */
    public function get_plugin_name()
    {
        return $this->plugin_name;
    }

    /**
     * The reference to the class that orchestrates the hooks with the plugin.
     *
     * @return    Pod_Plugin_Loader    Orchestrates the hooks of the plugin.
     * @since     1.0.0
     */
    public function get_loader()
    {
        return $this->loader;
    }

    /**
     * Retrieve the version number of the plugin.
     *
     * @return    string    The version number of the plugin.
     * @since     1.0.0
     */
    public function get_version()
    {
        return $this->version;
    }

}
